Module link

Module link 

Utilities for opening URLs in a new browser tab.

Functions

open
Open the given URL in a new browser tab by synthesizing a click on a transient anchor element with target="_blank".