pub fn declare(content: ContentList<'_>) -> Arc<Context>Expand description
Declare the given content entries on the global loader Context,
registering them for subsequent loading, and return that context.
pub fn declare(content: ContentList<'_>) -> Arc<Context>Declare the given content entries on the global loader Context,
registering them for subsequent loading, and return that context.